@@ -1,9 +1,10 @@
 /* poppler-qt.h: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, 2007, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2008, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2010, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Stefan Kebekus <stefan.kebekus@math.uni-koeln.de>
- * Copyright (C) 2006-2008, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2006-2009, Pino Toscano <pino@kde.org>
+ * Copyright (C) 2009 Shawn Rutledge <shawn.t.rutledge@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -218,6 +219,60 @@ namespace Poppler {
     };
 
 
+    class FontIteratorData;
+    /**
+       Iterator for reading the fonts in a document.
+
+       FontIterator provides a Java-style iterator for reading the fonts in a
+       document.
+
+       You can use it in the following way:
+       \code
+Poppler::FontIterator* it = doc->newFontIterator();
+while (it->hasNext()) {
+  QList<Poppler::FontInfo> fonts = it->next();
+  // do something with the fonts
+}
+// after doing the job, the iterator must be freed
+delete it;
+       \endcode
+
+       \since 0.12
+    */
+    class POPPLER_QT4_EXPORT FontIterator {
+    friend class Document;
+    friend class DocumentData;
+    public:
+	/**
+	   Destructor.
+	*/
+	~FontIterator();
+
+	/**
+	   Returns the fonts of the current page and then advances the iterator
+	   to the next page.
+	*/
+	QList<FontInfo> next();
+
+	/**
+	   Checks whether there is at least one more page to iterate, ie returns
+	   false when the iterator is beyond the last page.
+	*/
+	bool hasNext() const;
+
+	/**
+	   Returns the current page where the iterator is.
+	*/
+	int currentPage() const;
+
+    private:
+	Q_DISABLE_COPY( FontIterator )
+	FontIterator( int, DocumentData *dd );
+
+	FontIteratorData *d;
+    };
+
+
     class EmbeddedFileData;
     /**
        Container class for an embedded file with a PDF document
@@ -281,6 +336,13 @@ namespace Poppler {
 	*/
 	QByteArray data();
 
+	/**
+	   Is the embedded file valid?
+	   
+	   \since 0.12
+	*/
+	bool isValid() const;
+
 	/**
 	   A QDataStream for the actual data?
 	*/
@@ -366,6 +428,16 @@ namespace Poppler {
         */
 	QImage renderToImage(double xres=72.0, double yres=72.0, int x=-1, int y=-1, int w=-1, int h=-1, Rotation rotate = Rotate0) const;
 
+	/**
+	   Get the page thumbnail if it exists.
+
+	   \return a QImage of the thumbnail, or a null image
+	   if the PDF does not contain one for this page
+
+	   \since 0.12
+	*/
+	QImage thumbnail() const;
+
 	/**
 	   Returns the text that is inside a specified rectangle
 
@@ -400,8 +472,20 @@ namespace Poppler {
 	   \param caseSensitive be case sensitive?
 	   \param rotate the rotation to apply for the search order
 	**/
-	bool search(const QString &text, QRectF &rect, SearchDirection direction, SearchMode caseSensitive, Rotation rotate = Rotate0) const;
+	Q_DECL_DEPRECATED bool search(const QString &text, QRectF &rect, SearchDirection direction, SearchMode caseSensitive, Rotation rotate = Rotate0) const;
 	
+	/**
+	   Returns true if the specified text was found.
+
+	   \param text the text the search
+	   \param rectXXX in all directions is used to return where the text was found, for NextResult and PreviousResult
+	               indicates where to continue searching for
+	   \param direction in which direction do the search
+	   \param caseSensitive be case sensitive?
+	   \param rotate the rotation to apply for the search order
+	   \since 0.14
+	**/
+	bool search(const QString &text, double &rectLeft, double &rectTop, double &rectRight, double &rectBottom, SearchDirection direction, SearchMode caseSensitive, Rotation rotate = Rotate0) const;
 
 	/**
 	   Returns a list of text of the page
@@ -414,17 +498,20 @@ namespace Poppler {
 	   up-to-down), the QList contains the text in the proper
 	   order.
 
+	   \note The caller owns the text boxes and they should
+	         be deleted when no longer required.
+
 	   \warning This method is not tested with Asian scripts
 	*/
 	QList<TextBox*> textList(Rotation rotate = Rotate0) const;
 
 	/**
-	   \return The dimensions of the page, in points (i.e. 1/72th on an inch)
+	   \return The dimensions (cropbox) of the page, in points (i.e. 1/72th on an inch)
 	*/
 	QSizeF pageSizeF() const;
 
 	/**
-	   \return The dimensions of the page, in points (i.e. 1/72th on an inch)
+	   \return The dimensions (cropbox) of the page, in points (i.e. 1/72th on an inch)
 	*/
 	QSize pageSize() const;
 
@@ -539,13 +626,23 @@ namespace Poppler {
    \subsection document-rendering-backend Backends
 
    %Poppler offers a different backends for rendering the pages. Currently
-   there two backends (see #RenderBackend), but only the Splash engine works
+   there are two backends (see #RenderBackend), but only the Splash engine works
    well and has been tested.
 
    The available rendering backends can be discovered via availableRenderBackends().
    The current rendering backend can be changed using setRenderBackend().
    Please note that setting a backend not listed in the available ones
    will always result in null QImage's.
+
+   \section document-cms Color management support
+
+   %Poppler, if compiled with this support, provides functions to handle color
+   profiles.
+
+   To know whether the %Poppler version you are using has support for color
+   management, you can query Poppler::isCmsAvailable(). In case it is not
+   avilable, all the color management-related functions will either do nothing
+   or return null.
 */
     class POPPLER_QT4_EXPORT Document {
 	friend class Page;
@@ -594,10 +691,44 @@ namespace Poppler {
 	*/
 	enum RenderHint {
 	    Antialiasing = 0x00000001,      ///< Antialiasing for graphics
-	    TextAntialiasing = 0x00000002   ///< Antialiasing for text
+	    TextAntialiasing = 0x00000002,  ///< Antialiasing for text
+	    TextHinting = 0x00000004        ///< Hinting for text \since 0.12.1
 	};
 	Q_DECLARE_FLAGS( RenderHints, RenderHint )
 
+	/**
+	  Set a color display profile for the current document.
+
+	  \param outputProfileA is a \c cmsHPROFILE of the LCMS library.
+
+	   \since 0.12
+	*/
+	void setColorDisplayProfile(void *outputProfileA);
+	/**
+	  Set a color display profile for the current document.
+
+	  \param name is the name of the display profile to set.
+
+	   \since 0.12
+	*/
+	void setColorDisplayProfileName(const QString &name);
+	/**
+	  Return the current RGB profile.
+
+	  \return a \c cmsHPROFILE of the LCMS library.
+
+	   \since 0.12
+	*/
+	void* colorRgbProfile() const;
+	/**
+	  Return the current display profile.
+
+	  \return a \c cmsHPROFILE of the LCMS library.
+
+	   \since 0.12
+	*/
+	void *colorDisplayProfile() const;
+
 	/**
 	   Load the document from a file on disk
 
@@ -824,29 +955,74 @@ QString subject = m_doc->info("Subject");
 	/**
 	   The version of the PDF specification that the document
 	   conforms to
+
+	   \deprecated use getPdfVersion and avoid float point
+	   comparisons/handling
 	*/
-	double pdfVersion() const;
+	Q_DECL_DEPRECATED double pdfVersion() const;
+
+	/**
+	   The version of the PDF specification that the document
+	   conforms to
+
+	   \param major an optional pointer to a variable where store the
+	   "major" number of the version
+	   \param minor an optional pointer to a variable where store the
+	   "minor" number of the version
+
+	   \since 0.12
+	*/
+	void getPdfVersion(int *major, int *minor) const;
   
 	/**
 	   The fonts within the PDF document.
 
+	   This is a shorthand for getting all the fonts at once.
+
 	   \note this can take a very long time to run with a large
-	   document. You may wish to use the call below if you have more
+	   document. You may wish to use a FontIterator if you have more
 	   than say 20 pages
+
+	   \see newFontIterator()
 	*/
 	QList<FontInfo> fonts() const;
 
 	/**
-	   \overload
-
+	   Scans for fonts within the PDF document.
 
 	   \param numPages the number of pages to scan
 	   \param fontList pointer to the list where the font information
 	   should be placed
 
+	   \note with this method you can scan for fonts only \em once for each
+	   document; once the end is reached, no more scanning with this method
+	   can be done
+
 	   \return false if the end of the document has been reached
+
+	   \deprecated this function is quite limited in its job (see note),
+	   better use fonts() or newFontIterator()
+
+	   \see fonts(), newFontIterator()
 	*/
-	bool scanForFonts( int numPages, QList<FontInfo> *fontList ) const; 
+	Q_DECL_DEPRECATED bool scanForFonts( int numPages, QList<FontInfo> *fontList ) const;
+
+	/**
+	   Creates a new FontIterator object for font scanning.
+
+	   The new iterator can be used for reading the font information of the
+	   document, reading page by page.
+
+	   The caller is responsible for the returned object, ie it should freed
+	   it when no more useful.
+
+	   \param startPage the initial page from which start reading fonts
+
+	   \see fonts()
+
+	   \since 0.12
+	*/
+	FontIterator* newFontIterator( int startPage = 0 ) const;
 
 	/**
 	   The font data if the font is an embedded one.
@@ -1063,6 +1239,20 @@ QString subject = m_doc->info("Subject");
               \return whether the conversion succeeded
             */
             virtual bool convert() = 0;
+            
+            enum Error
+            {
+                NoError,
+                FileLockedError,
+                OpenOutputError,
+                NotSupportedInputFileError
+            };
+            
+            /**
+              Returns the last error
+              \since 0.12.1
+            */
+            Error lastError() const;
 
         protected:
             /// \cond PRIVATE
@@ -1246,6 +1436,13 @@ height = dummy.height();
     */
     POPPLER_QT4_EXPORT QDateTime convertDate( char *dateString );
 
+    /**
+       Whether the color management functions are available.
+
+       \since 0.12
+    */
+    POPPLER_QT4_EXPORT bool isCmsAvailable();
+
     class SoundData;
     /**
        Container class for a sound file in a PDF document.
